#
# spec file for package dvdauthor
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dvdauthor
Version:        0.7.2
Release:        4.2
Summary:        Low-level DVD Authoring Tools
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Video/Editors and Convertors
Url:            http://dvdauthor.sourceforge.net/
Source0:        https://github.com/ldo/dvdauthor/archive/%{version}.tar.gz#/dvdauthor-%{version}.tar.gz
#PATCH-FIX-UPSTREAM dvdauthor-0.7.0_glibc-2.20.patch avvissu@yandex.ru -- Fix build with glibc-2.20
Patch0:         dvdauthor-0.7.0_glibc-2.20.patch
Patch1:         dvdauthor-0.7.2-imagemagick7.patch
BuildRequires:  ImageMagick-devel
BuildRequires:  bison
BuildRequires:  docbook-utils
BuildRequires:  flex
BuildRequires:  libpng-devel
BuildRequires:  libtool
BuildRequires:  openjade
BuildRequires:  pkgconfig
BuildRequires:  texlive-booktabs
BuildRequires:  texlive-currfile
BuildRequires:  texlive-dviasm-bin
BuildRequires:  texlive-footmisc
BuildRequires:  texlive-koma-script
BuildRequires:  texlive-luatexbase
BuildRequires:  pkgconfig(dvdread)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(fribidi)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(zlib)
Provides:       dvdauthor07 = %{version}
Obsoletes:      dvdauthor07 <= %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
dvdauthor is a program that will generate a DVD-Video movie from a
valid MPEG-2 stream. To start you need MPEG-2 files that contain
the necessary DVD-Video VOB packets. These can be generated with
FFmpeg, or by by passing `-f 8` to `mplex`.

%prep
%autosetup -p1

%build
%if 1 == 0
%define gcc_version 7
export CC=gcc-7
export CPP=cpp-7
export CXX=g++-7
%endif
./bootstrap
# export MAGICK_CFLAGS=`ImageMagick-config --cppflags`
# export CFLAGS="%{optflags} $MAGICK_CFLAGS"
export LDFLAGS="$LDFLAGS -Wl,-z -Wl,noexecstack"
%configure
make %{?_smp_mflags}

%install
%make_install

%files
%defattr(-,root,root)
%doc COPYING README TODO AUTHORS ChangeLog
%{_bindir}/*
%{_mandir}/man*/*
%dir %{_datadir}/dvdauthor
%{_datadir}/dvdauthor/*

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Sun Apr 19 2020 tiwai@suse.de
- Revert to ImageMagick from GraphicsMagick due to the spumux error
  (boo#1169848)
- Fix the build with ImageMagick 7, a downstream patch taken from
  Arch linux package:
  dvdauthor-0.7.2-imagemagick7.patch
* Thu Jun  1 2017 alarrosa@suse.com
- Obsolete dvdauthor07 <= %%version-%%release instead of only older
  versions in order to fix conflicts on TW.
* Sat Apr  8 2017 davejplater@gmail.com
- Build with GraphicsMagick instead of ImageMagick due to the
  latter's change of api being incompatible.
* Tue Apr  4 2017 davejplater@gmail.com
- Update to version 0.7.2
- Upstream changes:
  * Various code-quality and build improvements
  * Support “jump pgc n” and other interaction code-generation
    improvements
  * Improve reliability of dvdunauthor
  * Don’t force infinite pause on last cell of a PGC
  * Allow specification of provider field in VMG IFO file
  * Add video_format(7) man page
  * Add padding to ensure .BUP and .IFO files end up in different
    ECC blocks
  * Enabled hinting of rendered subtitle text
  * Require cell start and end times (if specified) to be nonempty
* Sun Oct 23 2016 davejplater@gmail.com
- Update to version 0.7.1+ and rebased
  dvdauthor-0.7.0_glibc-2.20.patch
- Upstream fixed https://github.com/ldo/dvdauthor/issues/21
- Upstream changes:
  * Various code-quality and build improvements
  * Support “jump pgc n” and other interaction code-generation
    improvements
  * Improve reliability of dvdunauthor
  * Don’t force infinite pause on last cell of a PGC
  * Allow specification of provider field in VMG IFO file
  * Add video_format(7) man page
  * Add padding to ensure .BUP and .IFO files end up in different
    ECC blocks
  * No longer silently fail to build dvdunauthor if libdvdread is
    not present, must be explicitly disabled with
  - -disable-dvdunauthor, otherwise configure reports an error
  * Allow format specification at top level of dvdauthor control
    file
  * mpeg2desc now reports more details about video frames
  * More explanatory XML-parsing errors
* Tue Oct 21 2014 avvissu@yandex.ru
- Fix build error on openSUSE > 13.1:
  * add dvdauthor-0.7.0_glibc-2.20.patch
- Spec file cleanup
* Mon Apr  9 2012 davejplater@gmail.com
- Provided and obsoleted dvdauthor due to the dvdauthor binaries
  being overwritten during a zypper up -r Packman causing DVDStyler
  to fail.
* Mon May  2 2011 davejplater@gmail.com
- Update to version 0.7.0+ and removed dvdauthor-strcat.patch due to
  build errors and changes to the function patched.
* Sat Apr 16 2011 detlef@links2linux.de
- new upstream version <0.7.0>
* Sun Mar 21 2010 ludwig.nussel@gmx.de
- fix compile error instead of disabling post-build-checks
* Fri Mar 19 2010 detlef@links2linux.de
- new upstream version <0.6.18>
  * implement link-subset jumps
  * implement audio and subpicture content attributes
  * use dynamically-sized buffer for building IFO files
  * version jump to forestall fork confusion
* Fri Mar 12 2010 detlef@links2linux.de
- new upstream version <0.6.15>
  * consistently check for errors on all file opens and when creating output
    directories
  * fix remapping of colours for more than 8 subpicture streams
  * recover from SCR moving backwards as per suggestion from Philippe Sarazin
  * add patch from Wolfgang Wershofen to print out chapter timecodes
  * validate all XML integer arguments and attribute values
  * fix spurious error parsing video caption option
  * incorporate Fedora patch from Ville Skyttä to allow building with
    GraphicsMagick instead of ImageMagick
  * incorporate FriBidi patches from Ville Skyttä
  * auto-action buttons have spatial extents too
  * fill in more details in man pages
  * include an adaptation of Martin Crossley's ivtv patch
* Tue Feb 27 2007 rainer@links2linux.de
- new upstream release
* Tue Nov 25 2003 rainer@links2linux.de
- added some docs
* Fri Nov 14 2003 rainer@links2linux.de
- added menu.txt
* Mon Nov  3 2003 rainer@links2linux.de
- added DESTDIR patch
- first packman release
  Fri Feb 21 00:00:00 UTC 2003 - Dr. Peter Bieringer <pb at bieringer dot de> 0.4.3
- initial
